@@ -1,6 +1,6 @@
 
 options <- function( ... ){
-	structure( base:::options( ... ), class = "options" )
+	structure( base::options( ... ), class = "options" )
 }
 
 print.options <- function( x, ... ){
@@ -8,7 +8,7 @@ print.options <- function( x, ... ){
 }
 
 with.options <- function( data, expr, ...){
-	old.op <- data; on.exit( base:::options( old.op ) )
+	old.op <- data; on.exit( base::options( old.op ) )
 	out <- eval( substitute( expr ) )
 	attr( out, "withOptions" ) <- options()[names(old.op)]
 	class( out ) <- c( "withOptions", class(out) )
@@ -16,8 +16,8 @@ with.options <- function( data, expr, ...){
 }
 
 print.withOptions <- function( x, verbose = getOption("verbose"), ...){
-	old.op <- do.call( base:::options, attr(x, "withOptions" ) )
-	on.exit(base:::options(old.op))
+	old.op <- do.call( base::options, attr(x, "withOptions" ) )
+	on.exit(base::options(old.op))
 	if(verbose) cat ( "with options", paste( "\n", names(old.op), ":", old.op) ) 
 	class( x ) <- setdiff( class(x), "withOptions" )
 	print( x, ... )
